#[non_exhaustive]pub struct ListConstraintsRequest {
pub parent: String,
pub page_size: i32,
pub page_token: String,
/* private fields */
}Expand description
The request sent to the [ListConstraints] [google.cloud.orgpolicy.v2.OrgPolicy.ListConstraints] method.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.parent: StringRequired. The Google Cloud resource that parents the constraint. Must be in one of the following forms:
projects/{project_number}projects/{project_id}folders/{folder_id}organizations/{organization_id}
page_size: i32Size of the pages to be returned. This is currently unsupported and will be ignored. The server may at any point start using this field to limit page size.
page_token: StringPage token used to retrieve the next page. This is currently unsupported and will be ignored. The server may at any point start using this field.
Implementations
Sourceimpl ListConstraintsRequest
impl ListConstraintsRequest
Sourcepub fn set_parent<T: Into<String>>(self, v: T) -> Self
pub fn set_parent<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_page_size<T: Into<i32>>(self, v: T) -> Self
pub fn set_page_size<T: Into<i32>>(self, v: T) -> Self
Sourcepub fn set_page_token<T: Into<String>>(self, v: T) -> Self
pub fn set_page_token<T: Into<String>>(self, v: T) -> Self
Sets the value of page_token.
Example
ⓘ
let x = ListConstraintsRequest::new().set_page_token("example");Trait Implementations
Sourceimpl Clone for ListConstraintsRequest
impl Clone for ListConstraintsRequest
Sourcefn clone(&self) -> ListConstraintsRequest
fn clone(&self) -> ListConstraintsRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ListConstraintsRequest
impl Debug for ListConstraintsRequest
Sourceimpl Default for ListConstraintsRequest
impl Default for ListConstraintsRequest
Sourcefn default() -> ListConstraintsRequest
fn default() -> ListConstraintsRequest
Returns the “default value” for a type. Read more
Sourceimpl Message for ListConstraintsRequest
impl Message for ListConstraintsRequest
Sourceimpl PartialEq for ListConstraintsRequest
impl PartialEq for ListConstraintsRequest
Sourcefn eq(&self, other: &ListConstraintsRequest) -> bool
fn eq(&self, other: &ListConstraintsRequest) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for ListConstraintsRequest