#[non_exhaustive]pub struct ListCustomConstraintsRequest {
pub parent: String,
pub page_size: i32,
pub page_token: String,
/* private fields */
}Expand description
The request sent to the [ListCustomConstraints] [google.cloud.orgpolicy.v2.OrgPolicy.ListCustomConstraints] method.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.parent: StringRequired. The target Google Cloud resource that parents the set of custom constraints that will be returned from this call. Must be in one of the following forms:
organizations/{organization_id}
page_size: i32Size of the pages to be returned. This is currently unsupported and will be ignored. The server may at any point start using this field to limit page size.
page_token: StringPage token used to retrieve the next page. This is currently unsupported and will be ignored. The server may at any point start using this field.
Implementations
Sourceimpl ListCustomConstraintsRequest
impl ListCustomConstraintsRequest
Sourcepub fn set_parent<T: Into<String>>(self, v: T) -> Self
pub fn set_parent<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_page_size<T: Into<i32>>(self, v: T) -> Self
pub fn set_page_size<T: Into<i32>>(self, v: T) -> Self
Sourcepub fn set_page_token<T: Into<String>>(self, v: T) -> Self
pub fn set_page_token<T: Into<String>>(self, v: T) -> Self
Sets the value of page_token.
Example
ⓘ
let x = ListCustomConstraintsRequest::new().set_page_token("example");Trait Implementations
Sourceimpl Clone for ListCustomConstraintsRequest
impl Clone for ListCustomConstraintsRequest
Sourcefn clone(&self) -> ListCustomConstraintsRequest
fn clone(&self) -> ListCustomConstraintsRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ListCustomConstraintsRequest
impl Debug for ListCustomConstraintsRequest
Sourceimpl Default for ListCustomConstraintsRequest
impl Default for ListCustomConstraintsRequest
Sourcefn default() -> ListCustomConstraintsRequest
fn default() -> ListCustomConstraintsRequest
Returns the “default value” for a type. Read more
Sourceimpl PartialEq for ListCustomConstraintsRequest
impl PartialEq for ListCustomConstraintsRequest
Sourcefn eq(&self, other: &ListCustomConstraintsRequest) -> bool
fn eq(&self, other: &ListCustomConstraintsRequest) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for ListCustomConstraintsRequest