#[non_exhaustive]pub struct ListCustomConstraintsResponse {
pub custom_constraints: Vec<CustomConstraint>,
pub next_page_token: String,
/* private fields */
}Expand description
The response returned from the [ListCustomConstraints] [google.cloud.orgpolicy.v2.OrgPolicy.ListCustomConstraints] method. It will be empty if no custom or managed constraints are set on the organization resource.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.custom_constraints: Vec<CustomConstraint>All custom and managed constraints that exist on the organization resource. It will be empty if no custom constraints are set.
next_page_token: StringPage token used to retrieve the next page. This is currently not used, but the server may at any point start supplying a valid token.
Implementations
Sourceimpl ListCustomConstraintsResponse
impl ListCustomConstraintsResponse
Sourcepub fn set_custom_constraints<T, V>(self, v: T) -> Self
pub fn set_custom_constraints<T, V>(self, v: T) -> Self
Sets the value of custom_constraints.
Example
ⓘ
use google_cloud_orgpolicy_v2::model::CustomConstraint;
let x = ListCustomConstraintsResponse::new()
.set_custom_constraints([
CustomConstraint::default()/* use setters */,
CustomConstraint::default()/* use (different) setters */,
]);Sourcepub fn set_next_page_token<T: Into<String>>(self, v: T) -> Self
pub fn set_next_page_token<T: Into<String>>(self, v: T) -> Self
Sets the value of next_page_token.
Example
ⓘ
let x = ListCustomConstraintsResponse::new().set_next_page_token("example");Trait Implementations
Sourceimpl Clone for ListCustomConstraintsResponse
impl Clone for ListCustomConstraintsResponse
Sourcefn clone(&self) -> ListCustomConstraintsResponse
fn clone(&self) -> ListCustomConstraintsResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for ListCustomConstraintsResponse
impl Default for ListCustomConstraintsResponse
Sourcefn default() -> ListCustomConstraintsResponse
fn default() -> ListCustomConstraintsResponse
Returns the “default value” for a type. Read more
Sourceimpl PartialEq for ListCustomConstraintsResponse
impl PartialEq for ListCustomConstraintsResponse
Sourcefn eq(&self, other: &ListCustomConstraintsResponse) -> bool
fn eq(&self, other: &ListCustomConstraintsResponse) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for ListCustomConstraintsResponse