PolicySpec

Struct PolicySpec 

#[non_exhaustive]
pub struct PolicySpec { pub etag: String, pub update_time: Option<Timestamp>, pub rules: Vec<PolicyRule>, pub inherit_from_parent: bool, pub reset: bool, /* private fields */ }
Defines a Google Cloud policy specification which is used to specify constraints for configurations of Google Cloud resources.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
etag: String

An opaque tag indicating the current version of the policySpec, used for concurrency control.

This field is ignored if used in a CreatePolicy request.

When the policy is returned from either a GetPolicy or a ListPolicies request, this etag indicates the version of the current policySpec to use when executing a read-modify-write loop.

When the policy is returned from a GetEffectivePolicy request, the etag will be unset.

update_time: Option<Timestamp>

Output only. The time stamp this was previously updated. This represents the last time a call to CreatePolicy or UpdatePolicy was made for that policy.

rules: Vec<PolicyRule>

In policies for boolean constraints, the following requirements apply:

  • There must be one and only one policy rule where condition is unset.
  • Boolean policy rules with conditions must set enforced to the opposite of the policy rule without a condition.
  • During policy evaluation, policy rules with conditions that are true for a target resource take precedence.
inherit_from_parent: bool

Determines the inheritance behavior for this policy.

If inherit_from_parent is true, policy rules set higher up in the hierarchy (up to the closest root) are inherited and present in the effective policy. If it is false, then no rules are inherited, and this policy becomes the new root for evaluation. This field can be set only for policies which configure list constraints.

reset: bool

Ignores policies set above this resource and restores the constraint_default enforcement behavior of the specific constraint at this resource. This field can be set in policies for either list or boolean constraints. If set, rules must be empty and inherit_from_parent must be set to false.

Implementations

Source

impl PolicySpec

pub fn new() -> Self

Creates a new default instance.

pub fn set_etag<T: Into<String>>(self, v: T) -> Self

Sets the value of etag.

Example
let x = PolicySpec::new().set_etag("example");
pub fn set_update_time<T>(self, v: T) -> Self
where T: Into<Timestamp>,

Sets the value of update_time.

Example
use wkt::Timestamp;
let x = PolicySpec::new().set_update_time(Timestamp::default()/* use setters */);
pub fn set_or_clear_update_time<T>(self, v: Option<T>) -> Self
where T: Into<Timestamp>,

Sets or clears the value of update_time.

Example
use wkt::Timestamp;
let x = PolicySpec::new().set_or_clear_update_time(Some(Timestamp::default()/* use setters */));
let x = PolicySpec::new().set_or_clear_update_time(None::<Timestamp>);
pub fn set_rules<T, V>(self, v: T) -> Self
where T: IntoIterator<Item = V>, V: Into<PolicyRule>,

Sets the value of rules.

Example
use google_cloud_orgpolicy_v2::model::policy_spec::PolicyRule;
let x = PolicySpec::new()
    .set_rules([
        PolicyRule::default()/* use setters */,
        PolicyRule::default()/* use (different) setters */,
    ]);
pub fn set_inherit_from_parent<T: Into<bool>>(self, v: T) -> Self

Sets the value of inherit_from_parent.

Example
let x = PolicySpec::new().set_inherit_from_parent(true);
pub fn set_reset<T: Into<bool>>(self, v: T) -> Self

Sets the value of reset.

Example
let x = PolicySpec::new().set_reset(true);