#[non_exhaustive]pub struct UpdatePolicyRequest {
pub policy: Option<Policy>,
pub update_mask: Option<FieldMask>,
/* private fields */
}Expand description
The request sent to the UpdatePolicyRequest [google.cloud.orgpolicy.v2.OrgPolicy.UpdatePolicy] method.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.policy: Option<Policy>Required. Policy to update.
update_mask: Option<FieldMask>Field mask used to specify the fields to be overwritten in the policy by the set. The fields specified in the update_mask are relative to the policy, not the full request.
Implementations
Sourceimpl UpdatePolicyRequest
impl UpdatePolicyRequest
Sourcepub fn set_policy<T>(self, v: T) -> Self
pub fn set_policy<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_policy<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_policy<T>(self, v: Option<T>) -> Self
Sourcepub fn set_update_mask<T>(self, v: T) -> Self
pub fn set_update_mask<T>(self, v: T) -> Self
Sets the value of update_mask.
Example
ⓘ
use wkt::FieldMask;
let x = UpdatePolicyRequest::new().set_update_mask(FieldMask::default()/* use setters */);Sourcepub fn set_or_clear_update_mask<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_update_mask<T>(self, v: Option<T>) -> Self
Sets or clears the value of update_mask.
Example
ⓘ
use wkt::FieldMask;
let x = UpdatePolicyRequest::new().set_or_clear_update_mask(Some(FieldMask::default()/* use setters */));
let x = UpdatePolicyRequest::new().set_or_clear_update_mask(None::<FieldMask>);Trait Implementations
Sourceimpl Clone for UpdatePolicyRequest
impl Clone for UpdatePolicyRequest
Sourcefn clone(&self) -> UpdatePolicyRequest
fn clone(&self) -> UpdatePolicyRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for UpdatePolicyRequest
impl Debug for UpdatePolicyRequest
Sourceimpl Default for UpdatePolicyRequest
impl Default for UpdatePolicyRequest
Sourcefn default() -> UpdatePolicyRequest
fn default() -> UpdatePolicyRequest
Returns the “default value” for a type. Read more
Sourceimpl Message for UpdatePolicyRequest
impl Message for UpdatePolicyRequest
Sourceimpl PartialEq for UpdatePolicyRequest
impl PartialEq for UpdatePolicyRequest
Sourcefn eq(&self, other: &UpdatePolicyRequest) -> bool
fn eq(&self, other: &UpdatePolicyRequest) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for UpdatePolicyRequest