#[non_exhaustive]pub struct PolicySpec {
pub etag: String,
pub update_time: Option<Timestamp>,
pub rules: Vec<PolicyRule>,
pub inherit_from_parent: bool,
pub reset: bool,
/* private fields */
}Expand description
Defines a Google Cloud policy specification which is used to specify constraints for configurations of Google Cloud resources.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.etag: StringAn opaque tag indicating the current version of the policySpec, used for concurrency control.
This field is ignored if used in a CreatePolicy request.
When the policy is returned from either a GetPolicy or a
ListPolicies request, this etag indicates the version of the
current policySpec to use when executing a read-modify-write loop.
When the policy is returned from a GetEffectivePolicy request, the
etag will be unset.
update_time: Option<Timestamp>Output only. The time stamp this was previously updated. This
represents the last time a call to CreatePolicy or UpdatePolicy was
made for that policy.
rules: Vec<PolicyRule>In policies for boolean constraints, the following requirements apply:
- There must be one and only one policy rule where condition is unset.
- Boolean policy rules with conditions must set
enforcedto the opposite of the policy rule without a condition. - During policy evaluation, policy rules with conditions that are true for a target resource take precedence.
inherit_from_parent: boolDetermines the inheritance behavior for this policy.
If inherit_from_parent is true, policy rules set higher up in the
hierarchy (up to the closest root) are inherited and present in the
effective policy. If it is false, then no rules are inherited, and this
policy becomes the new root for evaluation.
This field can be set only for policies which configure list constraints.
reset: boolIgnores policies set above this resource and restores the
constraint_default enforcement behavior of the specific constraint at
this resource.
This field can be set in policies for either list or boolean
constraints. If set, rules must be empty and inherit_from_parent
must be set to false.
Implementations
Sourceimpl PolicySpec
impl PolicySpec
Sourcepub fn set_update_time<T>(self, v: T) -> Self
pub fn set_update_time<T>(self, v: T) -> Self
Sets the value of update_time.
Example
use wkt::Timestamp;
let x = PolicySpec::new().set_update_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_update_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_update_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of update_time.
Example
use wkt::Timestamp;
let x = PolicySpec::new().set_or_clear_update_time(Some(Timestamp::default()/* use setters */));
let x = PolicySpec::new().set_or_clear_update_time(None::<Timestamp>);Sourcepub fn set_inherit_from_parent<T: Into<bool>>(self, v: T) -> Self
pub fn set_inherit_from_parent<T: Into<bool>>(self, v: T) -> Self
Sets the value of inherit_from_parent.
Example
let x = PolicySpec::new().set_inherit_from_parent(true);Trait Implementations
Sourceimpl Clone for PolicySpec
impl Clone for PolicySpec
Sourcefn clone(&self) -> PolicySpec
fn clone(&self) -> PolicySpec
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for PolicySpec
impl Debug for PolicySpec
Sourceimpl Default for PolicySpec
impl Default for PolicySpec
Sourcefn default() -> PolicySpec
fn default() -> PolicySpec
Sourceimpl PartialEq for PolicySpec
impl PartialEq for PolicySpec
Sourcefn eq(&self, other: &PolicySpec) -> bool
fn eq(&self, other: &PolicySpec) -> bool
self and other values to be equal, and is used by ==.